//+------------------------------------------------------------------+
//|C:\Program Files\MetaTrader4Alpary\experts\Moving Average.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#define MAGICMA  20050610
//------------------------------------------------------------------------------
#include <sampledll.mqh> 
//------------------------------------------------------------------------------
extern double Lots               = 0.1;
extern double MaximumRisk        = 0.02;
extern double DecreaseFactor     = 3;
extern double MovingPeriod       = 12;
extern double MovingShift        = 11;//6; dll
//------------------------------------------------------------------------------------------
//| Calculate open positions                                         
//------------------------------------------------------------------------------------------
int CalculateCurrentOrders(string symbol){
   
   int   buys = 0, 
         sells =0;

   for( int i=0; i<OrdersTotal(); i++ ){
      if( OrderSelect(i,SELECT_BY_POS,MODE_TRADES) == false) break;
      if( OrderSymbol() == Symbol() && OrderMagicNumber() == MAGICMA){
         if( OrderType() == OP_BUY)  buys++;
         if( OrderType() == OP_SELL) sells++;
      }
   }
   // return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
}
//------------------------------------------------------------------------------------------
// Calculate optimal lot size                                       
//------------------------------------------------------------------------------------------
double LotsOptimized() {

   double lot = Lots;
   int    orders = HistoryTotal();  // history orders total
   int    losses = 0;               // number of losses orders without a break

   // select lot size
   lot=NormalizeDouble( AccountFreeMargin()*MaximumRisk/1000.0,1 );
   // calcuulate number of losses orders without a break
   if(DecreaseFactor>0) {
      for(int i=orders-1; i>=0; i--) {
         if( OrderSelect(i,SELECT_BY_POS,MODE_HISTORY) == false) { 
            Print("Error in history!"); 
            break; 
         }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         if( OrderProfit() > 0) break;
         if( OrderProfit() < 0) losses++;
      }
      if(losses>1) lot = NormalizeDouble( lot-lot*losses/DecreaseFactor ,1 );
   }
   if(lot<0.1) lot=0.1;
   return(lot);
}
//------------------------------------------------------------------------------------------
// Check for open order conditions                                  
//------------------------------------------------------------------------------------------
void CheckForOpen() {
   
   double ma;
   int   res,
         err;
   ///*
   // cd C:\Program Files\MetaTrader 4\tester\files\somefile.dat
   int handle = FileOpen( "somefile.dat",  FILE_CSV | FILE_WRITE, ' ');
   if( handle < 1 ) {
      err = GetLastError();
      Print("ErrOpenFile=", GetLastError());   //ErrorDescription(err) );
      //return(0);
   }
   if( handle > 0 )  {
      FileWrite( handle, TimeToStr( CurTime(), TIME_DATE | TIME_MINUTES ),"   " ,
                                    Close[0],   //      
                                    Open[0],    //        
                                    High[0],    //       
                                    Low[0] );   //      
      FileClose(handle);
   }
   //*/
   // go trading only for first tiks of new bar
   // Volume[0] -,       
   if( Volume[0] > 1 ) return;  

   // get Moving Average ==>   . 
   ma = iMA( NULL, 0, MovingPeriod, MovingShift, MODE_SMA, PRICE_CLOSE, 0 );

   // sell conditions
   // Open[1] -,       
   if( Open[1] > ma && Close[1] < ma ) {
      res = OrderSend(  Symbol(),   //        .  
                                    //   ,     
                        OP_SELL,    //  .       . 
                        LotsOptimized(),  //  .
                        Bid,     //  . 
                        3,       //        (    ).
                        0,       //        (0     ).
                        0,       //        (0     
                        "",      //   .        
                        MAGICMA, //   .      .
                        0,       //    .
                        Red );   //     
      return;
   }

   // buy conditions
   if( Open[1]<ma && Close[1]>ma ) {
      res = OrderSend( Symbol(), OP_BUY, LotsOptimized(), Ask,3,0,0,"", MAGICMA,0,Blue );
      return;
   }
}

//------------------------------------------------------------------------------------------
// Check for close order conditions                                 
//------------------------------------------------------------------------------------------
void CheckForClose() {

   double ma;
 
   // go trading only for first tiks of new bar
   if( Volume[0]>1 ) return;  //      

   // get Moving Average ==>   . 
   ma = iMA(   NULL, //   ,      . NULL    
               0,    // .      . 0     
               MovingPeriod,  //      . 
               MovingShift,   //     
               MODE_SMA,      //  .         (Moving Average).
               PRICE_CLOSE,   //  .      .
               0 );           //       (        ).
   
   // OrdersTotal() -       .
   for(int i=0; i<OrdersTotal(); i++) {
      //       
      if( OrderSelect(i, SELECT_BY_POS, MODE_TRADES) == false )        break;
      
      //   ("")    
      if( OrderMagicNumber()!=MAGICMA || OrderSymbol() != Symbol())  continue;
      
      //       ==> check order type 
      if( OrderType() == OP_BUY) {  // 
         // - ,       
         if( Open[1]>ma && Close[1]<ma ) 
            OrderClose( OrderTicket(), //       
                        OrderLots(),   //      
                        Bid,           //     BYE
                        3,             //     
                        MediumSpringGreen);//White);        //     
         break;
      }
      
      if( OrderType() == OP_SELL) { // 
         if( Open[1]<ma && Close[1]>ma ) 
            OrderClose( OrderTicket(), //       
                        OrderLots(),   //      
                        Ask,           //     SELL
                        3,             //     
                        MediumSpringGreen);//White);        //     
         break;
      }
   }
}

//------------------------------------------------------------------------------------------
// Start function                                                   
//------------------------------------------------------------------------------------------
void start() {

   int handle;
   //Print("0_Bars=", Bars);
   double some_value = 10.5;
   int    cnt;
   cnt = GetIntValue(some_value);
   //cnt = GetIntValue1(some_value);
   Print("Returned value is ",cnt);
   
   
   if( Bars<100 || IsTradeAllowed() == false) {    // check for history and trading
      Print("ErrBars=", Bars);
      return;
   }
   // calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol()) ==0 ) {
      //Print("---------OpenCheck----------", GetLastError());
      CheckForOpen();
   }
   else  {
      //Print("---------CloseCheck----------", GetLastError());
      CheckForClose();
   }
}
//------------------------------------------------------------------

